@@ -8,7 +8,7 @@ typedef struct semanage_iface_key record_key_t;
 
 struct dbase_file;
 typedef struct dbase_file dbase_t;
-#define DBASE_DEFINED 
+#define DBASE_DEFINED
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -19,16 +19,15 @@ typedef struct dbase_file dbase_t;
 #include "parse_utils.h"
 #include "debug.h"
 
-static int iface_print(
-	semanage_handle_t* handle,
-	semanage_iface_t* iface, 
-	FILE* str) {
+static int iface_print(semanage_handle_t * handle,
+		       semanage_iface_t * iface, FILE * str)
+{
 
-	char* con_str = NULL;
+	char *con_str = NULL;
 
-	const char* name = semanage_iface_get_name(iface);
-	semanage_context_t* ifcon = semanage_iface_get_ifcon(iface);
-	semanage_context_t* msgcon = semanage_iface_get_msgcon(iface);
+	const char *name = semanage_iface_get_name(iface);
+	semanage_context_t *ifcon = semanage_iface_get_ifcon(iface);
+	semanage_context_t *msgcon = semanage_iface_get_msgcon(iface);
 
 	if (fprintf(str, "netifcon %s ", name) < 0)
 		goto err;
@@ -46,28 +45,27 @@ static int iface_print(
 		goto err;
 	free(con_str);
 	con_str = NULL;
-	
+
 	return STATUS_SUCCESS;
 
-	err:
+      err:
 	ERR(handle, "could not print interface %s to stream", name);
 	free(con_str);
 	return STATUS_ERR;
 }
 
-static int iface_parse(
-	semanage_handle_t* handle,
-	parse_info_t* info, 
-	semanage_iface_t* iface) {
+static int iface_parse(semanage_handle_t * handle,
+		       parse_info_t * info, semanage_iface_t * iface)
+{
 
-	char* str = NULL;
-	semanage_context_t* con = NULL;
+	char *str = NULL;
+	semanage_context_t *con = NULL;
 
 	if (parse_skip_space(handle, info) < 0)
 		goto err;
 	if (!info->ptr)
 		goto last;
-	
+
 	/* Header */
 	if (parse_assert_str(handle, info, "netifcon") < 0)
 		goto err;
@@ -76,8 +74,8 @@ static int iface_parse(
 
 	/* Name */
 	if (parse_fetch_string(handle, info, &str, ' ') < 0)
-		goto err;		
-	if (semanage_iface_set_name(handle, iface, str)  < 0)
+		goto err;
+	if (semanage_iface_set_name(handle, iface, str) < 0)
 		goto err;
 	free(str);
 	str = NULL;
@@ -89,18 +87,18 @@ static int iface_parse(
 		goto err;
 	if (semanage_context_from_string(handle, str, &con) < 0) {
 		ERR(handle, "invalid security context \"%s\" (%s: %u)\n%s",
-			str, info->filename, info->lineno, info->orig_line);
+		    str, info->filename, info->lineno, info->orig_line);
 		goto err;
 	}
 	if (con == NULL) {
 		ERR(handle, "<<none>> context is not valid for "
-			"interfaces (%s: %u)\n%s", info->filename,
-			info->lineno, info->orig_line);
+		    "interfaces (%s: %u)\n%s", info->filename,
+		    info->lineno, info->orig_line);
 		goto err;
 	}
 	free(str);
 	str = NULL;
-	
+
 	if (semanage_iface_set_ifcon(handle, iface, con) < 0)
 		goto err;
 	semanage_context_free(con);
@@ -113,13 +111,13 @@ static int iface_parse(
 		goto err;
 	if (semanage_context_from_string(handle, str, &con) < 0) {
 		ERR(handle, "invalid security context \"%s\" (%s: %u)\n%s",
-			str, info->filename, info->lineno, info->orig_line);
+		    str, info->filename, info->lineno, info->orig_line);
 		goto err;
 	}
 	if (con == NULL) {
 		ERR(handle, "<<none>> context is not valid for "
-			"interfaces (%s: %u)\n%s", info->filename, 
-			info->lineno, info->orig_line);
+		    "interfaces (%s: %u)\n%s", info->filename,
+		    info->lineno, info->orig_line);
 		goto err;
 	}
 	free(str);
@@ -128,18 +126,18 @@ static int iface_parse(
 	if (semanage_iface_set_msgcon(handle, iface, con) < 0)
 		goto err;
 	semanage_context_free(con);
-	con = NULL;	
+	con = NULL;
 
 	if (parse_assert_space(handle, info) < 0)
 		goto err;
 
 	return STATUS_SUCCESS;
 
-	last:
+      last:
 	parse_dispose_line(info);
 	return STATUS_NODATA;
 
-	err:
+      err:
 	ERR(handle, "could not parse interface record");
 	free(str);
 	semanage_context_free(con);
@@ -149,29 +147,26 @@ static int iface_parse(
 
 /* IFACE RECORD: FILE extension: method table */
 record_file_table_t SEMANAGE_IFACE_FILE_RTABLE = {
-	.parse       = iface_parse,
-	.print       = iface_print,
+	.parse = iface_parse,
+	.print = iface_print,
 };
 
-int iface_file_dbase_init(
-	semanage_handle_t* handle,
-	const char* fname, 
-	dbase_config_t* dconfig) {
-	
-	if (dbase_file_init(
-		handle,
-		fname, 
-		&SEMANAGE_IFACE_RTABLE,
-		&SEMANAGE_IFACE_FILE_RTABLE, 
-		&dconfig->dbase) < 0)
+int iface_file_dbase_init(semanage_handle_t * handle,
+			  const char *fname, dbase_config_t * dconfig)
+{
+
+	if (dbase_file_init(handle,
+			    fname,
+			    &SEMANAGE_IFACE_RTABLE,
+			    &SEMANAGE_IFACE_FILE_RTABLE, &dconfig->dbase) < 0)
 		return STATUS_ERR;
 
 	dconfig->dtable = &SEMANAGE_FILE_DTABLE;
 	return STATUS_SUCCESS;
 }
 
-void iface_file_dbase_release(
-	dbase_config_t* dconfig) {
+void iface_file_dbase_release(dbase_config_t * dconfig)
+{
 
 	dbase_file_release(dconfig->dbase);
 }
