@@ -19,35 +19,33 @@ typedef struct dbase_file dbase_t;
 #include "debug.h"
 #include "handle.h"
 
-static int seuser_print(
-	semanage_handle_t* handle,
-	semanage_seuser_t* seuser, 
-	FILE* str) {
+static int seuser_print(semanage_handle_t * handle,
+			semanage_seuser_t * seuser, FILE * str)
+{
 
-	const char* name = semanage_seuser_get_name(seuser);
-	const char* sename = semanage_seuser_get_sename(seuser);
-	const char* mls = semanage_seuser_get_mlsrange(seuser);
+	const char *name = semanage_seuser_get_name(seuser);
+	const char *sename = semanage_seuser_get_sename(seuser);
+	const char *mls = semanage_seuser_get_mlsrange(seuser);
 
-	if (fprintf(str, "%s:%s", name, sename) < 0) 
+	if (fprintf(str, "%s:%s", name, sename) < 0)
 		goto err;
-	
-	if (mls != NULL && fprintf(str, ":%s", mls) <  0)
+
+	if (mls != NULL && fprintf(str, ":%s", mls) < 0)
 		goto err;
-	
+
 	fprintf(str, "\n");
 	return STATUS_SUCCESS;
 
-	err:
+      err:
 	ERR(handle, "could not print seuser %s to stream", name);
 	return STATUS_ERR;
 }
 
-static int seuser_parse(
-	semanage_handle_t* handle,
-	parse_info_t* info, 
-	semanage_seuser_t* seuser) {
+static int seuser_parse(semanage_handle_t * handle,
+			parse_info_t * info, semanage_seuser_t * seuser)
+{
 
-	char* str = NULL;
+	char *str = NULL;
 
 	if (parse_skip_space(handle, info) < 0)
 		goto err;
@@ -88,22 +86,22 @@ static int seuser_parse(
 	if (parse_fetch_string(handle, info, &str, ' ') < 0)
 		goto err;
 
-	if (semanage_seuser_set_mlsrange(handle, seuser, str) <  0)
+	if (semanage_seuser_set_mlsrange(handle, seuser, str) < 0)
 		goto err;
 	free(str);
 	str = NULL;
 
 	if (parse_assert_space(handle, info) < 0)
-		goto err; 
-	
-	out:
+		goto err;
+
+      out:
 	return STATUS_SUCCESS;
 
-	last:
+      last:
 	parse_dispose_line(info);
 	return STATUS_NODATA;
 
-	err:
+      err:
 	ERR(handle, "could not parse seuser record");
 	free(str);
 	parse_dispose_line(info);
@@ -112,29 +110,26 @@ static int seuser_parse(
 
 /* SEUSER RECORD: FILE extension: method table */
 record_file_table_t SEMANAGE_SEUSER_FILE_RTABLE = {
-	.parse       = seuser_parse,
-	.print       = seuser_print,
+	.parse = seuser_parse,
+	.print = seuser_print,
 };
 
-int seuser_file_dbase_init(
-	semanage_handle_t* handle,
-	const char* fname, 
-	dbase_config_t* dconfig) {
+int seuser_file_dbase_init(semanage_handle_t * handle,
+			   const char *fname, dbase_config_t * dconfig)
+{
 
-	if (dbase_file_init(
-		handle, 
-		fname,
-		&SEMANAGE_SEUSER_RTABLE,
-		&SEMANAGE_SEUSER_FILE_RTABLE,
-		&dconfig->dbase) < 0)
+	if (dbase_file_init(handle,
+			    fname,
+			    &SEMANAGE_SEUSER_RTABLE,
+			    &SEMANAGE_SEUSER_FILE_RTABLE, &dconfig->dbase) < 0)
 		return STATUS_ERR;
 
 	dconfig->dtable = &SEMANAGE_FILE_DTABLE;
 	return STATUS_SUCCESS;
 }
 
-void seuser_file_dbase_release(
-	dbase_config_t* dconfig) {
+void seuser_file_dbase_release(dbase_config_t * dconfig)
+{
 
 	dbase_file_release(dconfig->dbase);
 }
